Struct MaybeStructured

pub struct MaybeStructured<'a, T>
where T: ?Sized,
{ /* private fields */ }
A wrapper around a generic type that can be used to construct for insertion.

Implementations

Source

impl<'a, T> MaybeStructured<'a, T>
where T: 'a + Type + ?Sized,

pub fn encoded_len(&self) -> usize

Returns the encoded length.

pub fn encode(&self, buf: &mut [u8]) -> Result<usize, <T as Type>::Error>

Encodes the generic into the buffer.

Panics
  • if the buffer is not large enough.
pub fn encode_to_buffer( &self, buf: &mut VacantBuffer<'_>, ) -> Result<usize, <T as Type>::Error>

Encodes the generic into the given buffer.

Panics
  • if the buffer is not large enough.
Source

impl<'a, T> MaybeStructured<'a, T>
where T: 'a + ?Sized,

pub const fn data(&self) -> Either<&'a T, &'a [u8]>

Returns the value contained in the generic.

pub const unsafe fn from_slice(slice: &'a [u8]) -> MaybeStructured<'a, T>

Creates a new unstructured MaybeStructured from bytes for querying or inserting.

Safety
  • the slice must the same as the one returned by T::encode.