Struct ValueBuilder

pub struct ValueBuilder<F> {
    pub size: usize,
    pub f: F,
}
A value builder for the wal, which requires the value size for accurate allocation and a closure to build the value.

Fields

size: usize

The required size of the builder.

f: F

The builder closure.

Implementations

Source

impl<F> ValueBuilder<F>

pub const fn new(size: usize, f: F) -> Self

Creates a new ValueBuilder with the given size and builder closure.

pub const fn size(&self) -> usize

Returns the required ValueBuilder size.

pub const fn builder(&self) -> &F

Returns the ValueBuilder builder closure.

pub fn into_components(self) -> (usize, F)

Deconstructs the value builder into the size and the builder closure.

Source

impl<F> ValueBuilder<F>

pub const fn once<E>(size: usize, f: F) -> Self
where F: for<'a> FnOnce(&mut VacantBuffer<'a>) -> Result<usize, E>,

Creates a new ValueBuilder with the given size and builder closure which requires FnOnce.