pub struct ValueBuilder<F> {
pub size: usize,
pub f: F,
}Expand description
A value builder for the wal, which requires the value size for accurate allocation and a closure to build the value.
Fields
size: usizeThe required size of the builder.
f: FThe builder closure.
Implementations
Sourceimpl<F> ValueBuilder<F>
impl<F> ValueBuilder<F>
Sourceimpl<F> ValueBuilder<F>
impl<F> ValueBuilder<F>